<?php

/**
 * @version     1.0.0
 * @package     com_resonlinebooking
 * @copyright   Copyright (C) 2014. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      binhk32xp <binhk32xp@gmail.com> - http://eku.com
 */
defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Resonlinebooking records.
 */
class ResonlinebookingModelBookinglist extends JModelList {

    /**
     * Constructor.
     *
     * @param    array    An optional associative array of configuration settings.
     * @see        JController
     * @since    1.6
     */
    public function __construct($config = array()) {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                                'id', 'a.id',
                'bookingName', 'a.bookingName',
                'hotelID', 'a.hotelID',
                'defaultAdults', 'a.defaultAdults',
                'defaultNights', 'a.defaultNights',
                'autoTickedNights', 'a.autoTickedNights',
                'primaryColor', 'a.primaryColor',
                'defaultChildren', 'a.defaultChildren',
                'specialsOnly', 'a.specialsOnly',
                'secondaryColor', 'a.secondaryColor',
                'defaultGridColumns', 'a.defaultGridColumns',
                'promoteSpecials', 'a.promoteSpecials',
                'bookingButtonMode', 'a.bookingButtonMode',
                'dayOffset', 'a.dayOffset',
                'defaultCurrency', 'a.defaultCurrency',
                'defaultDate', 'a.defaultDate',
                'maxChildren', 'a.maxChildren',
                'defaultDaysOut', 'a.defaultDaysOut',
                'errorUrl', 'a.errorUrl',
                'gridLabel', 'a.gridLabel',
                'inSiteCheck', 'a.inSiteCheck',
                'layout', 'a.layout',
                'maxAdults', 'a.maxAdults',
                'maxImages', 'a.maxImages',
                'maxNights', 'a.maxNights',
                'minNights', 'a.minNights',
                'minNightsFilter', 'a.minNightsFilter',
                'multiPropsExpanded', 'a.multiPropsExpanded',
                'multiPropsInfoLink', 'a.multiPropsInfoLink',
                'multiPropsOneGrid', 'a.multiPropsOneGrid',
                'newWindow', 'a.newWindow',
                'privateApartment', 'a.privateApartment',
                'ratePlanFilter', 'a.ratePlanFilter',
                'separateGrid', 'a.separateGrid',
                'showCurrency', 'a.showCurrency',
                'showGrid', 'a.showGrid',
                'showImage', 'a.showImage',
                'showInclusions', 'a.showInclusions',
                'showPropertyDetails', 'a.showPropertyDetails',
                'showRoomTypeDetails', 'a.showRoomTypeDetails',
                'specificRatePlan', 'a.specificRatePlan',
                'useAnalytics', 'a.useAnalytics',
                'webID', 'a.webID',

            );
        }

        parent::__construct($config);
    }

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     */
    protected function populateState($ordering = null, $direction = null) {
        // Initialise variables.
        $app = JFactory::getApplication('administrator');

        // Load the filter state.
        $search = $app->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
        $this->setState('filter.search', $search);

        $published = $app->getUserStateFromRequest($this->context . '.filter.state', 'filter_published', '', 'string');
        $this->setState('filter.state', $published);

        

        // Load the parameters.
        $params = JComponentHelper::getParams('com_resonlinebooking');
        $this->setState('params', $params);

        // List state information.
        parent::populateState('a.id', 'asc');
    }

    /**
     * Method to get a store id based on model configuration state.
     *
     * This is necessary because the model is used by the component and
     * different modules that might need different sets of data or different
     * ordering requirements.
     *
     * @param	string		$id	A prefix for the store id.
     * @return	string		A store id.
     * @since	1.6
     */
    protected function getStoreId($id = '') {
        // Compile the store id.
        $id.= ':' . $this->getState('filter.search');
        $id.= ':' . $this->getState('filter.state');

        return parent::getStoreId($id);
    }

    /**
     * Build an SQL query to load the list data.
     *
     * @return	JDatabaseQuery
     * @since	1.6
     */
    protected function getListQuery() {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        // Select the required fields from the table.
        $query->select(
                $this->getState(
                        'list.select', 'DISTINCT a.*'
                )
        );
        $query->from('`#__resonlinebooking` AS a');

        

        

        // Filter by search in title
        $search = $this->getState('filter.search');
        if (!empty($search)) {
            if (stripos($search, 'id:') === 0) {
                $query->where('a.id = ' . (int) substr($search, 3));
            } else {
                $search = $db->Quote('%' . $db->escape($search, true) . '%');
                
            }
        }

        


        // Add the list ordering clause.
        $orderCol = $this->state->get('list.ordering');
        $orderDirn = $this->state->get('list.direction');
        if ($orderCol && $orderDirn) {
            $query->order($db->escape($orderCol . ' ' . $orderDirn));
        }

        return $query;
    }

    public function getItems() {
        $items = parent::getItems();
        
        return $items;
    }

}
